##  Advanced: TIME or 6R Assessment to Identify and Track Key Changes through the Transformation
As part of the Discovery phase, we also recommend running either a [TIME](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD) assessment and/or a [6R](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD) assessment as a good EA practice - depending on your transformation goals. This will help you get more out of the big transformation effort, and it will also provide you with KPIs you can use to track what will happen with your application landscape as part of the transformation. Moreover, it is one way of visualizing the current vs. future state of your application landscape.
![TIME Classification of Applications clustered by Business Capabilities](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274394947a44101493caee1ebd25e312_LowRes.png)
TIME Classification of Applications clustered by Business Capabilities
